@@ -26,7 +26,9 @@ const Test = require('./test.js');
 function TestAgent(app, options = {}) {
   if (!(this instanceof TestAgent)) return new TestAgent(app, options);
 
-  Agent.call(this, options);
+  const agent = new Agent(options);
+  Object.assign(this, agent);
+
   this._options = options;
 
   if (typeof app === 'function') {
